import React from 'react'
import { H3 } from '@pubsweet/ui'
import { get, has } from 'lodash'
import styled from 'styled-components'
import { th } from '@pubsweet/ui-toolkit'
import { withRouter } from 'react-router-dom'
import { ManuscriptCard, Row } from 'pubsweet-component-faraday-ui'
import { compose, setDisplayName, withHandlers } from 'recompose'

import withVersion from './withVersion'

const DashboardItem = withVersion(ManuscriptCard)

const DashboardItems = ({ onClick, list, deleteProject }) => (
  <Root>
    {!list.length ? (
      <Row justify="center" mt={4}>
        <H3>Manuscripts will appear here!</H3>
      </Row>
    ) : (
      list.map(collection => (
        // <HideLoading>
        <DashboardItem
          collection={collection}
          key={collection.id}
          onClick={onClick}
          onDelete={() => deleteProject(collection)}
        />
        // </HideLoading>
      ))
    )}
  </Root>
)

export default compose(
  withRouter,
  withHandlers({
    onClick: ({ history }) => (collection, fragment) => {
      const hasDetails = get(collection, 'status', 'draft') !== 'draft'
      const isNotSubmitted =
        get(collection, 'status', 'draft') === 'draft' &&
        !has(fragment, 'submitted')
      if (isNotSubmitted) {
        history.push(
          `/projects/${collection.id}/versions/${fragment.id}/submit`,
        )
      } else if (hasDetails) {
        history.push(
          `/projects/${collection.id}/versions/${fragment.id}/details`,
        )
      }
    },
  }),
  setDisplayName('DashboardItems'),
)(DashboardItems)

// #region styles
const Root = styled.div`
  height: calc(100vh - ${th('gridUnit')} * 21);
  overflow-y: auto;
  padding-right: ${th('gridUnit')};
  overflow-x: hidden;
  div[open] {
    width: auto;
  }
`
// const HideLoading = styled.div`
//   > div {
//     display: none;
//   }
//   > div[data-test-id|='fragment'] {
//     display: flex;
//   }
// `
// #endregion
