import React from 'react'
import { connect } from 'react-redux'
import { Button, H2, Spinner } from '@pubsweet/ui'
import { Row, ShadowedBox, Text } from 'pubsweet-component-faraday-ui'
import { compose, lifecycle, withState } from 'recompose'

import { parseSearchParams } from '../utils'
import { confirmUser } from '../../redux/users'

const loading = `Loading...`
const confirmTitle = `Welcome to Hindawi!`
const confirmSubtitle = `Your account has been successfully confirmed.`
const errorTitle = `Something went wrong...`
const errorSubtitle = `Please try again.`

const ConfirmAccount = ({ message: { title, subtitle }, history }) => (
  <ShadowedBox>
    <H2>{title}</H2>
    <Row mb={title !== errorTitle ? 2 : 0} mt={2}>
      <Text>{subtitle}</Text>
    </Row>
    {title !== errorTitle && (
      <Row>
        {title === loading ? (
          <Spinner />
        ) : (
          <Button onClick={() => history.replace('/')} primary>
            Go to Dashboard
          </Button>
        )}
      </Row>
    )}
  </ShadowedBox>
)

export default compose(
  connect(null, { confirmUser }),
  withState('message', 'setConfirmMessage', {
    title: loading,
  }),
  lifecycle({
    componentDidMount() {
      const { location, confirmUser, setConfirmMessage } = this.props
      const { confirmationToken, userId } = parseSearchParams(location.search)

      if (userId) {
        confirmUser(userId, confirmationToken)
          .then(() => {
            setConfirmMessage({
              title: confirmTitle,
              subtitle: confirmSubtitle,
            })
          })
          .catch(() => {
            // errors are still gobbled up by pubsweet
            setConfirmMessage({
              title: errorTitle,
              subtitle: errorSubtitle,
            })
          })
      }
    },
  }),
)(ConfirmAccount)
