import React, { Fragment } from 'react'
import { reduxForm } from 'redux-form'
import { required } from 'xpub-validators'
import { Button, ValidatedField, TextField } from '@pubsweet/ui'
import { Row, Item, Label, Text } from 'pubsweet-component-faraday-ui'

import { passwordValidator, emailValidator } from '../utils'

const PasswordField = input => <TextField {...input} type="password" />
const EmailField = input => <TextField {...input} type="email" />

const SignUpForm = () => (
  <Fragment>
    <Row mb={2}>
      <Item vertical>
        <Label required>Email</Label>
        <ValidatedField
          component={EmailField}
          name="email"
          validate={[required, emailValidator]}
        />
      </Item>
    </Row>
    <Row mb={2}>
      <Item vertical>
        <Label required>Password</Label>
        <ValidatedField
          component={PasswordField}
          name="password"
          validate={[required]}
        />
      </Item>
    </Row>
    <Row mb={2}>
      <Item vertical>
        <Label required>Confirm password</Label>
        <ValidatedField
          component={PasswordField}
          name="confirmPassword"
          validate={[required]}
        />
      </Item>
    </Row>
  </Fragment>
)

const InviteForm = () => (
  <Fragment>
    <Row mb={2} mt={2}>
      <Item vertical>
        <Label required>Password</Label>
        <ValidatedField
          component={PasswordField}
          name="password"
          validate={[required]}
        />
      </Item>
    </Row>
    <Row mb={2}>
      <Item vertical>
        <Label required>Confirm password</Label>
        <ValidatedField
          component={PasswordField}
          name="confirmPassword"
          validate={[required]}
        />
      </Item>
    </Row>
  </Fragment>
)

const ForgotEmailForm = () => (
  <Fragment>
    <Row mb={2} mt={2}>
      <Item vertical>
        <Label required>Email</Label>
        <ValidatedField
          component={EmailField}
          name="email"
          validate={[required, emailValidator]}
        />
      </Item>
    </Row>
  </Fragment>
)

const withoutBack = ['setPassword']
const Step1 = ({
  error,
  onBack,
  submitting,
  onSubmitText,
  handleSubmit,
  type = 'invite',
}) => (
  <Fragment>
    {type === 'signup' && <SignUpForm />}
    {type === 'setPassword' && <InviteForm />}
    {type === 'forgotPassword' && <ForgotEmailForm />}
    {type === 'invite' && <InviteForm />}
    {error && (
      <Row justify="flex-start" mb={1}>
        <Text error>{error}</Text>
      </Row>
    )}
    <Row />

    <Row justify={!withoutBack.includes(type) ? 'space-between' : 'center'}>
      {!withoutBack.includes(type) && <Button onClick={onBack}>BACK</Button>}
      <Button disabled={submitting} onClick={handleSubmit} primary>
        {onSubmitText}
      </Button>
    </Row>
  </Fragment>
)

export default reduxForm({
  form: 'signUpInvitation',
  destroyOnUnmount: false,
  forceUnregisterOnUnmount: true,
  validate: passwordValidator,
})(Step1)
