import React from 'react'
import { compose } from 'recompose'
import { connect } from 'react-redux'
import { reduxForm } from 'redux-form'
import { required } from 'xpub-validators'
import { selectCurrentUser } from 'xpub-selectors'
import { Button, H2, TextField, ValidatedField } from '@pubsweet/ui'
import {
  Row,
  Item,
  Text,
  Label,
  ShadowedBox,
} from 'pubsweet-component-faraday-ui'

import {
  changePasswordValidator,
  onSubmitChangePassword as onSubmit,
} from '../utils'

const PasswordField = input => <TextField {...input} type="password" />

const ChangePassword = ({ history, handleSubmit, error }) => (
  <ShadowedBox center mt={10}>
    <H2>Change Password</H2>
    <Row mt={3}>
      <Item vertical>
        <Label required>Current Password</Label>
        <ValidatedField
          component={PasswordField}
          name="password"
          validate={[required]}
        />
      </Item>
    </Row>
    <Row mt={2}>
      <Item vertical>
        <Label required>New Password</Label>
        <ValidatedField
          component={PasswordField}
          name="newPassword"
          validate={[required]}
        />
      </Item>
    </Row>
    <Row mt={2}>
      <Item vertical>
        <Label required>Re-type password</Label>
        <ValidatedField
          component={PasswordField}
          name="confirmNewPassword"
          validate={[required]}
        />
      </Item>
    </Row>
    {error && (
      <Row mt={1}>
        <Item>
          <Text error>{error}</Text>
        </Item>
      </Row>
    )}
    <Row />
    <Row justify="space-between" mt={3}>
      <Button onClick={history.goBack}>Back</Button>
      <Button onClick={handleSubmit} primary>
        Update password
      </Button>
    </Row>
  </ShadowedBox>
)

export default compose(
  connect(state => ({
    user: selectCurrentUser(state),
  })),
  reduxForm({
    onSubmit,
    form: 'changePassword',
    validate: changePasswordValidator,
  }),
)(ChangePassword)

// #region styles
// #endregion
